==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkImageResliceToColors.java <==
// java wrapper for vtkImageResliceToColors object
//

package vtk;
import vtk.*;

public class vtkImageResliceToColors extends vtkImageReslice
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLookupTable_2(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_2(id0); }

  private native long GetLookupTable_3();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_3();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetOutputFormat_4(int id0);
  public void SetOutputFormat(int id0)
    { SetOutputFormat_4(id0); }

  private native int GetOutputFormatMinValue_5();
  public int GetOutputFormatMinValue()
    { return GetOutputFormatMinValue_5(); }

  private native int GetOutputFormatMaxValue_6();
  public int GetOutputFormatMaxValue()
    { return GetOutputFormatMaxValue_6(); }

  private native int GetOutputFormat_7();
  public int GetOutputFormat()
    { return GetOutputFormat_7(); }

  private native void SetOutputFormatToRGBA_8();
  public void SetOutputFormatToRGBA()
    { SetOutputFormatToRGBA_8(); }

  private native void SetOutputFormatToRGB_9();
  public void SetOutputFormatToRGB()
    { SetOutputFormatToRGB_9(); }

  private native void SetOutputFormatToLuminanceAlpha_10();
  public void SetOutputFormatToLuminanceAlpha()
    { SetOutputFormatToLuminanceAlpha_10(); }

  private native void SetOutputFormatToLuminance_11();
  public void SetOutputFormatToLuminance()
    { SetOutputFormatToLuminance_11(); }

  private native void SetBypass_12(int id0);
  public void SetBypass(int id0)
    { SetBypass_12(id0); }

  private native void BypassOn_13();
  public void BypassOn()
    { BypassOn_13(); }

  private native void BypassOff_14();
  public void BypassOff()
    { BypassOff_14(); }

  private native int GetBypass_15();
  public int GetBypass()
    { return GetBypass_15(); }

  private native int GetMTime_16();
  public int GetMTime()
    { return GetMTime_16(); }

  public vtkImageResliceToColors() { super(); }

  public vtkImageResliceToColors(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-aarch64.pkg.tar.xz: vtk/vtkImageResliceToColors.java <==
// java wrapper for vtkImageResliceToColors object
//

package vtk;
import vtk.*;

public class vtkImageResliceToColors extends vtkImageReslice
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLookupTable_2(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_2(id0); }

  private native long GetLookupTable_3();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_3();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutputFormat_4(int id0);
  public void SetOutputFormat(int id0)
    { SetOutputFormat_4(id0); }

  private native int GetOutputFormatMinValue_5();
  public int GetOutputFormatMinValue()
    { return GetOutputFormatMinValue_5(); }

  private native int GetOutputFormatMaxValue_6();
  public int GetOutputFormatMaxValue()
    { return GetOutputFormatMaxValue_6(); }

  private native int GetOutputFormat_7();
  public int GetOutputFormat()
    { return GetOutputFormat_7(); }

  private native void SetOutputFormatToRGBA_8();
  public void SetOutputFormatToRGBA()
    { SetOutputFormatToRGBA_8(); }

  private native void SetOutputFormatToRGB_9();
  public void SetOutputFormatToRGB()
    { SetOutputFormatToRGB_9(); }

  private native void SetOutputFormatToLuminanceAlpha_10();
  public void SetOutputFormatToLuminanceAlpha()
    { SetOutputFormatToLuminanceAlpha_10(); }

  private native void SetOutputFormatToLuminance_11();
  public void SetOutputFormatToLuminance()
    { SetOutputFormatToLuminance_11(); }

  private native void SetBypass_12(int id0);
  public void SetBypass(int id0)
    { SetBypass_12(id0); }

  private native void BypassOn_13();
  public void BypassOn()
    { BypassOn_13(); }

  private native void BypassOff_14();
  public void BypassOff()
    { BypassOff_14(); }

  private native int GetBypass_15();
  public int GetBypass()
    { return GetBypass_15(); }

  private native int GetMTime_16();
  public int GetMTime()
    { return GetMTime_16(); }

  public vtkImageResliceToColors() { super(); }

  public vtkImageResliceToColors(long id) { super(id); }
  public native long   VTKInit();

}
